Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1691)

Unified Diff: mojo/services/network/network_service_delegate.h

Issue 1290323002: HTMLViewer no longer connects to NetworkService interface. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: . Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/services/network/http_server_apptest.cc ('k') | mojo/services/network/network_service_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/services/network/network_service_delegate.h
diff --git a/mojo/services/network/network_service_delegate.h b/mojo/services/network/network_service_delegate.h
index 1d87e3ce342be4b2b00836152e3739ab00f1332b..216f9619f584584ad9ce46619fe67ee639c208e4 100644
--- a/mojo/services/network/network_service_delegate.h
+++ b/mojo/services/network/network_service_delegate.h
@@ -12,9 +12,10 @@
#include "mojo/application/public/cpp/application_impl.h"
#include "mojo/application/public/cpp/interface_factory.h"
#include "mojo/services/network/network_context.h"
+#include "mojo/services/network/public/interfaces/cookie_store.mojom.h"
#include "mojo/services/network/public/interfaces/network_service.mojom.h"
#include "mojo/services/network/public/interfaces/url_loader_factory.mojom.h"
-#include "third_party/mojo/src/mojo/public/cpp/bindings/interface_ptr.h"
+#include "mojo/services/network/public/interfaces/web_socket_factory.mojom.h"
namespace sql {
class ScopedMojoFilesystemVFS;
@@ -23,11 +24,12 @@ class ScopedMojoFilesystemVFS;
namespace mojo {
class NetworkServiceDelegateObserver;
-class NetworkServiceDelegate
- : public mojo::ApplicationDelegate,
- public mojo::InterfaceFactory<mojo::NetworkService>,
- public mojo::InterfaceFactory<mojo::URLLoaderFactory>,
- public filesystem::FileSystemClient {
+class NetworkServiceDelegate : public ApplicationDelegate,
+ public InterfaceFactory<NetworkService>,
+ public InterfaceFactory<CookieStore>,
+ public InterfaceFactory<WebSocketFactory>,
+ public InterfaceFactory<URLLoaderFactory>,
+ public filesystem::FileSystemClient {
public:
NetworkServiceDelegate();
~NetworkServiceDelegate() override;
@@ -40,31 +42,38 @@ class NetworkServiceDelegate
// multiple times.
void EnsureIOThreadShutdown();
- // mojo::ApplicationDelegate implementation.
- void Initialize(mojo::ApplicationImpl* app) override;
- bool ConfigureIncomingConnection(
- mojo::ApplicationConnection* connection) override;
+ // ApplicationDelegate implementation.
+ void Initialize(ApplicationImpl* app) override;
+ bool ConfigureIncomingConnection(ApplicationConnection* connection) override;
bool OnShellConnectionError() override;
void Quit() override;
- // mojo::InterfaceFactory<mojo::NetworkService> implementation.
- void Create(mojo::ApplicationConnection* connection,
- mojo::InterfaceRequest<mojo::NetworkService> request) override;
+ // InterfaceFactory<NetworkService> implementation.
+ void Create(ApplicationConnection* connection,
+ InterfaceRequest<NetworkService> request) override;
- // mojo::InterfaceFactory<mojo::URLLoaderFactory> implementation.
- void Create(mojo::ApplicationConnection* connection,
- mojo::InterfaceRequest<mojo::URLLoaderFactory> request) override;
+ // InterfaceFactory<CookieStore> implementation.
+ void Create(ApplicationConnection* connection,
+ InterfaceRequest<CookieStore> request) override;
+
+ // InterfaceFactory<WebSocketFactory> implementation.
+ void Create(ApplicationConnection* connection,
+ InterfaceRequest<WebSocketFactory> request) override;
+
+ // InterfaceFactory<URLLoaderFactory> implementation.
+ void Create(ApplicationConnection* connection,
+ InterfaceRequest<URLLoaderFactory> request) override;
// Overridden from FileSystemClient:
void OnFileSystemShutdown() override;
private:
- mojo::ApplicationImpl* app_;
+ ApplicationImpl* app_;
// Observers that want notifications that our worker thread is going away.
base::ObserverList<NetworkServiceDelegateObserver> observers_;
- mojo::Binding<filesystem::FileSystemClient> binding_;
+ Binding<filesystem::FileSystemClient> binding_;
// A worker thread that blocks for file IO.
scoped_ptr<base::Thread> io_worker_thread_;
@@ -73,7 +82,7 @@ class NetworkServiceDelegate
// other data.
filesystem::FileSystemPtr files_;
- scoped_ptr<mojo::NetworkContext> context_;
+ scoped_ptr<NetworkContext> context_;
};
} // namespace mojo
« no previous file with comments | « mojo/services/network/http_server_apptest.cc ('k') | mojo/services/network/network_service_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698